package de.draegerit.timeline;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;
import javax.servlet.http.Part;

import de.draegerit.timeline.entity.TimelineEntry;
import de.draegerit.timeline.entity.UploadFile;

@ManagedBean
@SessionScoped
public class TimelineFormular {

	private String title;
	private String text;
	private Part file;

	private TimelineStorage storage = new TimelineStorage();

	public void save() {
		TimelineEntry entry = new TimelineEntry();
		entry.setText(text);
		entry.setTitle(title);
		entry.setTimestamp(System.currentTimeMillis());

		if (file != null) {
			String originalFilename = extractFileNameFromPart(file).toUpperCase();
			if (originalFilename.endsWith(".PNG") || originalFilename.endsWith(".JPG")
					|| originalFilename.endsWith(".JPEG")) {
				String filename = generateFilename(originalFilename);
				try {
					FacesContext fC = FacesContext.getCurrentInstance();
					String relativeWebPath = "/images";
					String absoluteDiskPath = fC.getExternalContext().getRealPath(relativeWebPath);
					file.write(absoluteDiskPath + "\\" + filename);
				} catch (IOException e) {
					e.printStackTrace();
				}

				UploadFile file = new UploadFile();
				file.setFilename(filename);
				file.setOriginalFilename(originalFilename);
				entry.setFile(file);
			}
		}

		getStorage().store(entry);
	}

	private String extractFileNameFromPart(Part part) {
		String contentDisp = part.getHeader("content-disposition");
		String[] items = contentDisp.split(";");
		for (String s : items) {
			if (s.trim().startsWith("filename")) {
				return s.substring(s.indexOf("=") + 2, s.length() - 1);
			}
		}
		return "";
	}

	private String generateFilename(String filename) {
		if (filename.length() < 10) {
			filename = filename.concat("a3g7h2B90xR4eW");
		}
		String name = filename.substring(filename.lastIndexOf("\\") + 1, filename.lastIndexOf("."));
		List<Character> characters = new ArrayList<Character>();
		for (Character c : name.toCharArray()) {
			characters.add(c);
		}
		Collections.shuffle(characters);
		StringBuilder builder = new StringBuilder();
		for (Character c : characters) {
			builder.append(String.valueOf(c));
		}
		builder.append(".fle");
		return builder.toString();
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getText() {
		return text;
	}

	public void setText(String text) {
		this.text = text;
	}

	public TimelineStorage getStorage() {
		return storage;
	}

	public void setStorage(TimelineStorage storage) {
		this.storage = storage;
	}

	public Part getFile() {
		return file;
	}

	public void setFile(Part file) {
		this.file = file;
	}

}
